%global  _hardened_build     1
%global  nginx_user          nginx
%global  __brp_check_rpaths  %{nil}

# Disable strict symbol checks in the link editor.
# See: https://src.fedoraproject.org/rpms/redhat-rpm-config/c/078af19
%undefine _strict_symbol_defs_build

%bcond_with geoip

%bcond_with geoip2

%bcond_with brotli

%bcond_with fancyindex

%bcond_with rtmp

# gperftools exist only on selected arches
# gperftools *detection* is failing on ppc64*, possibly only configure
# bug, but disable anyway.
%ifnarch s390 s390x ppc64 ppc64le
%global with_gperftools 1
%endif

%global with_aio 1

%if 0%{?fedora} > 22
%global with_mailcap_mimetypes 1
%endif

# Cf. https://www.nginx.com/blog/creating-installable-packages-dynamic-modules/
%global nginx_abiversion %{version}

%global nginx_moduledir %{_libdir}/nginx/modules
%global nginx_moduleconfdir %{_datadir}/nginx/modules
%global nginx_srcdir %{_usrsrc}/%{name}-%{version}-%{release}

# Do not generate provides/requires from nginx sources
%global __provides_exclude_from ^%{nginx_srcdir}/.*$
%global __requires_exclude_from ^%{nginx_srcdir}/.*$

Name:              nginx
Epoch:             1
Version:           1.26.0
Release:           1%{?dist}

Summary:           A high performance web server and reverse proxy server
# BSD License (two clause)
# http://www.freebsd.org/copyright/freebsd-license.html
License:           BSD
URL:               http://nginx.org/

Source0:           nginx-%{version}.tar.gz
Source1:           nginx-%{version}.tar.gz.asc
# Keys are found here: http://nginx.org/en/pgp_keys.html
#Source2:           aalexeev.key
Source3:           https://nginx.org/keys/arut.key
Source4:           https://nginx.org/keys/maxim.key
Source5:           https://nginx.org/keys/pluknet.key
Source6:           https://nginx.org/keys/sb.key
Source7:           https://nginx.org/keys/thresh.key
Source8:           https://nginx.org/keys/nginx_signing.key
Source10:          nginx.service
Source11:          nginx.logrotate
Source12:          nginx.conf
Source13:          0-default.conf
Source15:          nginx-upgrade
Source16:          nginx-upgrade.8
Source17:          macros.nginxmods.in
Source18:          nginxmods.attr
Source20:          deny-restrictions.conf
%if %{with geoip2}
Source21:          geoip2.conf
%endif
Source22:          gzip.conf
%if %{with brotli}
Source23:          brotli.conf
%endif
Source24:          x-security.conf
Source100:         index.html
Source101:         poweredby.png
Source102:         nginx-logo.png
Source103:         404.html
Source104:         50x.html
Source200:         README.dynamic
%if %{with geoip2}
Source310:         ngx_http_geoip2_module-3.4.tar.gz
%endif
%if %{with brotli}
Source311:         ngx_brotli-1.0.0rc.tar.gz
%endif
%if %{with fancyindex}
Source312:         ngx-fancyindex-0.5.2.tar.xz
%endif
%if %{with rtmp}
Source313:         nginx-rtmp-module-1.2.2.tar.gz
%endif

BuildRequires:     gcc
%if 0%{?with_gperftools}
BuildRequires:     gperftools-devel
%endif
BuildRequires:     openssl-devel
BuildRequires:     pcre-devel
BuildRequires:     zlib-devel

Requires:          nginx-filesystem = %{epoch}:%{version}-%{release}

Requires:          openssl
Requires:          pcre
Requires(pre):     nginx-filesystem
%if 0%{?with_mailcap_mimetypes}
Requires:          nginx-mimetypes
%endif
Provides:          webserver

BuildRequires:     libmaxminddb-devel

BuildRequires:     systemd
Requires(post):    systemd
Requires(preun):   systemd
Requires(postun):  systemd

%description
Nginx is a web server and a reverse proxy server for HTTP, SMTP, POP3 and
IMAP protocols, with a strong focus on high concurrency, performance and low
memory usage.

%package core
Summary: nginx minimal core
%if 0%{?with_mailcap_mimetypes}
Requires:          nginx-mimetypes
%endif
Requires:          openssl%{?openssl_pkgversion}-libs
Requires(pre):     nginx-filesystem

%description core
nginx minimal core

%package all-modules
Summary:           A meta package that installs all available Nginx modules
BuildArch:         noarch

%if %{with geoip}
Requires:          nginx-mod-http-geoip = %{epoch}:%{version}-%{release}
%endif

%if %{with geoip2}
Requires:          nginx-mod-http-geoip2 = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-stream-geoip2 = %{epoch}:%{version}-%{release}
%endif

%if %{with brotli}
Requires:          nginx-mod-brotli-filter = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-brotli-static = %{epoch}:%{version}-%{release}
%endif

%if %{with fancyindex}
Requires:          nginx-mod-http-fancyindex = %{epoch}:%{version}-%{release}
%endif

%if %{with rtmp}
Requires:          nginx-mod-rtmp = %{epoch}:%{version}-%{release}
%endif

Requires:          nginx-mod-http-image-filter = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-http-perl = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-http-xslt-filter = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-mail = %{epoch}:%{version}-%{release}
Requires:          nginx-mod-stream = %{epoch}:%{version}-%{release}

%description all-modules
Meta package that installs all available nginx modules.

%package filesystem
Summary:           The basic directory layout for the Nginx server
BuildArch:         noarch
Requires(pre):     shadow-utils

%description filesystem
The nginx-filesystem package contains the basic directory layout
for the Nginx server including the correct permissions for the
directories.

%if %{with geoip}
%package mod-http-geoip
Summary:           Nginx HTTP geoip module
BuildRequires:     GeoIP-devel
Requires:          nginx
Requires:          GeoIP

%description mod-http-geoip
%{summary}.
%endif

%if %{with geoip2}
%package mod-http-geoip2
Summary:           Nginx HTTP geoip2 module
Requires:          nginx
Requires:          libmaxminddb

%description mod-http-geoip2
%{summary}.

%package mod-stream-geoip2
Summary:           Nginx stream geoip2 module
Requires:          nginx
Requires:          libmaxminddb

%description mod-stream-geoip2
%{summary}.
%endif

%if %{with brotli}
%package mod-http-brotli-filter
Summary:           Nginx HTTP brotli filter module
Requires:          nginx
Requires:          libbrotli

%description mod-http-brotli-filter
%{summary}.

%package mod-http-brotli-static
Summary:           Nginx HTTP brotli static module
Requires:          nginx
Requires:          libbrotli

%description mod-http-brotli-static
%{summary}.
%endif

%if %{with fancyindex}
%package mod-http-fancyindex
Summary:           Nginx HTTP fancyindex module
Requires:          nginx

%description mod-http-fancyindex
%{summary}.
%endif

%if %{with rtmp}
%package mod-rtmp
Summary:           Nginx RTMP module
Requires:          nginx

%description mod-rtmp
%{summary}.
%endif

%package mod-http-image-filter
Summary:           Nginx HTTP image filter module
BuildRequires:     gd-devel
Requires:          nginx
Requires:          gd

%description mod-http-image-filter
%{summary}.

%package mod-http-perl
Summary:           Nginx HTTP perl module
BuildRequires:     perl-devel
%if 0%{?fedora} >= 24
BuildRequires:     perl-generators
%endif
BuildRequires:     perl(ExtUtils::Embed)
Requires:          nginx
Requires:          perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires:          perl(constant)

%description mod-http-perl
%{summary}.

%package mod-http-xslt-filter
Summary:           Nginx XSLT module
BuildRequires:     libxslt-devel
Requires:          nginx

%description mod-http-xslt-filter
%{summary}.

%package mod-mail
Summary:           Nginx mail modules
Requires:          nginx

%description mod-mail
%{summary}.

%package mod-stream
Summary:           Nginx stream modules
Requires:          nginx

%description mod-stream
%{summary}.

%package mod-devel
Summary:           Nginx module development files
Requires:          nginx = %{epoch}:%{version}-%{release}
Requires:          make
Requires:          gcc
Requires:          gd-devel
%if 0%{?with_gperftools}
Requires:          gperftools-devel
%endif
%if %{with geoip}
Requires:          GeoIP-devel
%endif
%if %{with geoip2}
Requires:          libmaxminddb
%endif
%if %{with brotli}
Requires:          libbrotli
%endif
Requires:          libxslt-devel
%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:          openssl-devel
%else
Requires:          openssl11-devel
%endif
Requires:          pcre2-devel
Requires:          perl-devel
Requires:          perl(ExtUtils::Embed)
Requires:          zlib-devel

%description mod-devel
%{summary}.


%prep
mkdir -pv %{_builddir}/%{name}-%{version}
tar -xvf %{_sourcedir}/%{name}-%{version}.tar.gz --directory %{_builddir}/%{name}-%{version}
cat %{SOURCE3} %{SOURCE4} %{SOURCE5} %{SOURCE6} %{SOURCE7} > %{_builddir}/%{name}-%{version}/%{name}.gpg
# Combine all keys from upstream into one file
%{gpgverify} --keyring='%{_builddir}/%{name}-%{version}/%{name}.gpg' --signature='%{SOURCE1}' --data='%{SOURCE0}'
%setup -q
cp %{SOURCE200} %{SOURCE10} %{SOURCE12} .

%if 0%{?rhel} > 0 && 0%{?rhel} < 8
sed -i -e 's#KillMode=.*#KillMode=process#g' nginx.service
sed -i -e 's#PROFILE=SYSTEM#HIGH:!aNULL:!MD5#' nginx.conf
%endif

# Prepare sources for installation
cp -a ../%{name}-%{version} ../%{name}-%{version}-%{release}-src
mv ../%{name}-%{version}-%{release}-src .

%if %{with geoip2}
mkdir -pv %{_builddir}/%{name}-%{version}-modules
tar -xvf %{SOURCE310} --directory %{_builddir}/%{name}-%{version}-modules/
rm -rf %{_builddir}/%{name}-%{version}-modules/ngx_http_geoip2_module
mv %{_builddir}/%{name}-%{version}-modules/ngx_http_geoip2_module-3.4 %{_builddir}/%{name}-%{version}-modules/ngx_http_geoip2_module
%endif

%if %{with brotli}
mkdir -pv %{_builddir}/%{name}-%{version}-modules
tar -xvf %{SOURCE311} --directory %{_builddir}/%{name}-%{version}-modules/
rm -rf %{_builddir}/%{name}-%{version}-modules/ngx_brotli_module
mv %{_builddir}/%{name}-%{version}-modules/ngx_brotli-1.0.0rc %{_builddir}/%{name}-%{version}-modules/ngx_brotli_module
%endif

%if %{with fancyindex}
mkdir -pv %{_builddir}/%{name}-%{version}-modules
tar -xvf %{SOURCE312} --directory %{_builddir}/%{name}-%{version}-modules/
rm -rf %{_builddir}/%{name}-%{version}-modules/ngx_http_fancyindex_module
mv %{_builddir}/%{name}-%{version}-modules/ngx-fancyindex-0.5.2 %{_builddir}/%{name}-%{version}-modules/ngx_http_fancyindex_module
%endif

%if %{with rtmp}
mkdir -pv %{_builddir}/%{name}-%{version}-modules
tar -xvf %{SOURCE313} --directory %{_builddir}/%{name}-%{version}-modules/
rm -rf %{_builddir}/%{name}-%{version}-modules/ngx_rtmp_module
mv %{_builddir}/%{name}-%{version}-modules/nginx-rtmp-module-1.2.2 %{_builddir}/%{name}-%{version}-modules/ngx_rtmp_module
%endif


%build
# nginx does not utilize a standard configure script.  It has its own
# and the standard configure options cause the nginx configure script
# to error out.  This is is also the reason for the DESTDIR environment
# variable.
export DESTDIR=%{buildroot}
# So the perl module finds its symbols:
nginx_ldopts="$RPM_LD_FLAGS -Wl,-E"
if ! ./configure \
    --prefix=%{_datadir}/nginx \
    --sbin-path=%{_sbindir}/nginx \
    --modules-path=%{nginx_moduledir} \
    --conf-path=%{_sysconfdir}/nginx/nginx.conf \
    --error-log-path=%{_localstatedir}/log/nginx/error.log \
    --http-log-path=%{_localstatedir}/log/nginx/access.log \
    --http-client-body-temp-path=%{_localstatedir}/lib/nginx/tmp/client_body \
    --http-proxy-temp-path=%{_localstatedir}/lib/nginx/tmp/proxy \
    --http-fastcgi-temp-path=%{_localstatedir}/lib/nginx/tmp/fastcgi \
    --http-uwsgi-temp-path=%{_localstatedir}/lib/nginx/tmp/uwsgi \
    --http-scgi-temp-path=%{_localstatedir}/lib/nginx/tmp/scgi \
    --pid-path=/run/nginx.pid \
    --lock-path=/run/lock/subsys/nginx \
    --user=%{nginx_user} \
    --group=%{nginx_user} \
%if 0%{?with_aio}
    --with-file-aio \
%endif
    --with-http_ssl_module \
    --with-http_v2_module \
    --with-http_realip_module \
    --with-stream_ssl_preread_module \
    --with-http_addition_module \
    --with-http_xslt_module=dynamic \
    --with-http_image_filter_module=dynamic \
%if %{with geoip}
    --with-http_geoip_module=dynamic \
%endif
%if %{with geoip2}
    --add-dynamic-module=%{_builddir}/%{name}-%{version}-modules/ngx_http_geoip2_module \
%endif
%if %{with brotli}
    --add-dynamic-module=%{_builddir}/%{name}-%{version}-modules/ngx_brotli_module \
%endif
%if %{with fancyindex}
    --add-dynamic-module=%{_builddir}/%{name}-%{version}-modules/ngx_http_fancyindex_module \
%endif
%if %{with rtmp}
    --add-dynamic-module=%{_builddir}/%{name}-%{version}-modules/ngx_rtmp_module \
%endif
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_mp4_module \
    --with-http_gunzip_module \
    --with-http_gzip_static_module \
    --with-http_random_index_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_slice_module \
    --with-http_stub_status_module \
    --with-http_perl_module=dynamic \
    --with-http_auth_request_module \
    --with-mail=dynamic \
    --with-mail_ssl_module \
    --with-pcre \
    --with-pcre-jit \
    --with-stream=dynamic \
    --with-stream_realip_module \
    --with-stream_ssl_module \
    --with-threads \
%if 0%{?with_gperftools}
    --with-google_perftools_module \
%endif
    --with-debug \
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-ld-opt="$nginx_ldopts"; then
  : configure failed
  cat objs/autoconf.err
  exit 1
fi

make %{?_smp_mflags}


%install
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor

find %{buildroot} -type f -name .packlist -exec rm -f '{}' \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f '{}' \;
find %{buildroot} -type f -empty -exec rm -f '{}' \;
find %{buildroot} -type f -iname '*.so' -exec chmod 0755 '{}' \;

install -p -D -m 0644 ./nginx.service \
    %{buildroot}%{_unitdir}/nginx.service
install -p -D -m 0644 %{SOURCE11} \
    %{buildroot}%{_sysconfdir}/logrotate.d/nginx

install -p -d -m 0755 %{buildroot}%{_sysconfdir}/systemd/system/nginx.service.d
install -p -d -m 0755 %{buildroot}%{_unitdir}/nginx.service.d

install -p -d -m 0755 %{buildroot}%{_sysconfdir}/nginx/conf.d
%if %{with geoip2}
install -p -m 0644 %{SOURCE21} \
    %{buildroot}%{_sysconfdir}/nginx/conf.d/
%endif
install -p -m 0644 %{SOURCE24} \
    %{buildroot}%{_sysconfdir}/nginx/conf.d/

install -p -d -m 0755 %{buildroot}%{_sysconfdir}/nginx/default.d
install -p -D -m 0644 %{SOURCE20} \
    %{buildroot}%{_sysconfdir}/nginx/default.d/
install -p -D -m 0644 %{SOURCE22} \
    %{buildroot}%{_sysconfdir}/nginx/default.d/
%if %{with brotli}
install -p -m 0644 %{SOURCE23} \
    %{buildroot}%{_sysconfdir}/nginx/default.d/
%endif

install -p -d -m 0755 %{buildroot}%{_sysconfdir}/nginx/sites-available
install -p -d -m 0755 %{buildroot}%{_sysconfdir}/nginx/sites-enabled

install -p -d -m 0700 %{buildroot}%{_localstatedir}/lib/nginx
install -p -d -m 0700 %{buildroot}%{_localstatedir}/lib/nginx/tmp
install -p -d -m 0700 %{buildroot}%{_localstatedir}/log/nginx

install -p -d -m 0755 %{buildroot}%{_datadir}/nginx/html
install -p -d -m 0755 %{buildroot}%{nginx_moduleconfdir}
install -p -d -m 0755 %{buildroot}%{nginx_moduledir}

install -p -m 0644 nginx.conf \
    %{buildroot}%{_sysconfdir}/nginx
install -p -m 0644 %{SOURCE13} \
    %{buildroot}%{_sysconfdir}/nginx/sites-available
ln -s sites-available/0-default.conf %{buildroot}%{_sysconfdir}/nginx/sites-enabled/
install -p -m 0644 %{SOURCE100} \
    %{buildroot}%{_datadir}/nginx/html
install -p -m 0644 %{SOURCE101} %{SOURCE102} \
    %{buildroot}%{_datadir}/nginx/html
install -p -m 0644 %{SOURCE103} %{SOURCE104} \
    %{buildroot}%{_datadir}/nginx/html

%if 0%{?with_mailcap_mimetypes}
rm -f %{buildroot}%{_sysconfdir}/nginx/mime.types
%endif

install -p -D -m 0644 %{_builddir}/nginx-%{version}/objs/nginx.8 \
    %{buildroot}%{_mandir}/man8/nginx.8

install -p -D -m 0755 %{SOURCE15} %{buildroot}%{_bindir}/nginx-upgrade
install -p -D -m 0644 %{SOURCE16} %{buildroot}%{_mandir}/man8/nginx-upgrade.8

for i in ftdetect indent syntax; do
    install -p -D -m644 contrib/vim/${i}/nginx.vim \
        %{buildroot}%{_datadir}/vim/vimfiles/${i}/nginx.vim
done

%if %{with geoip}
echo 'load_module "%{nginx_moduledir}/ngx_http_geoip_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-geoip.conf
%endif

%if %{with geoip2}
echo 'load_module "%{nginx_moduledir}/ngx_http_geoip2_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-geoip2.conf
echo 'load_module "%{nginx_moduledir}/ngx_stream_geoip2_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-stream-geoip2.conf
%endif

%if %{with brotli}
echo 'load_module "%{nginx_moduledir}/ngx_http_brotli_filter_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-brotli-filter.conf
echo 'load_module "%{nginx_moduledir}/ngx_http_brotli_static_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-brotli-static.conf
%endif

%if %{with fancyindex}
echo 'load_module "%{nginx_moduledir}/ngx_http_fancyindex_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-fancyindex.conf
%endif

%if %{with rtmp}
echo 'load_module "%{nginx_moduledir}/ngx_rtmp_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-rtmp.conf
%endif

echo 'load_module "%{nginx_moduledir}/ngx_http_image_filter_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-image-filter.conf
echo 'load_module "%{nginx_moduledir}/ngx_http_perl_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-perl.conf
echo 'load_module "%{nginx_moduledir}/ngx_http_xslt_filter_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-http-xslt-filter.conf
echo 'load_module "%{nginx_moduledir}/ngx_mail_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-mail.conf
echo 'load_module "%{nginx_moduledir}/ngx_stream_module.so";' \
    > %{buildroot}%{nginx_moduleconfdir}/mod-stream.conf

# Install files for supporting nginx module builds
## Install source files
mkdir -p %{buildroot}%{_usrsrc}
mv %{name}-%{version}-%{release}-src %{buildroot}%{nginx_srcdir}
## Install rpm macros
mkdir -p %{buildroot}%{_rpmmacrodir}
sed -e "s|@@NGINX_ABIVERSION@@|%{nginx_abiversion}|g" \
    -e "s|@@NGINX_MODDIR@@|%{nginx_moduledir}|g" \
    -e "s|@@NGINX_MODCONFDIR@@|%{nginx_moduleconfdir}|g" \
    -e "s|@@NGINX_SRCDIR@@|%{nginx_srcdir}|g" \
    %{SOURCE17} > %{buildroot}%{_rpmmacrodir}/macros.nginxmods
## Install dependency generator
install -Dpm0644 %{SOURCE18} %{buildroot}%{_fileattrsdir}/nginxmods.attr


%pre filesystem
getent group %{nginx_user} > /dev/null || groupadd -r %{nginx_user}
getent passwd %{nginx_user} > /dev/null || \
    useradd -r -d %{_localstatedir}/lib/nginx -g %{nginx_user} \
    -s /sbin/nologin -c "Nginx web server" %{nginx_user}
exit 0

%post
%systemd_post nginx.service

%if %{with geoip}
%post mod-http-geoip
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%if %{with geoip2}
%post mod-http-geoip2
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%post mod-stream-geoip2
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%if %{with brotli}
%post mod-http-brotli-filter
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%post mod-http-brotli-static
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%if %{with fancyindex}
%post mod-http-fancyindex
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%if %{with rtmp}
%post mod-rtmp
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi
%endif

%post mod-http-image-filter
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-http-perl
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-http-xslt-filter
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-mail
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%post mod-stream
if [ $1 -eq 1 ]; then
    /usr/bin/systemctl reload nginx.service >/dev/null 2>&1 || :
fi

%preun
%systemd_preun nginx.service

%postun
%systemd_postun nginx.service
if [ $1 -ge 1 ]; then
    /usr/bin/nginx-upgrade >/dev/null 2>&1 || :
fi

%files
%license LICENSE
%doc CHANGES README README.dynamic
%{_datadir}/nginx/html/*
%{_bindir}/nginx-upgrade
%{_sbindir}/nginx
%{_datadir}/vim/vimfiles/ftdetect/nginx.vim
%{_datadir}/vim/vimfiles/syntax/nginx.vim
%{_datadir}/vim/vimfiles/indent/nginx.vim
%{_mandir}/man3/nginx.3pm*
%{_mandir}/man8/nginx.8*
%{_mandir}/man8/nginx-upgrade.8*
%{_unitdir}/nginx.service
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf.default
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/koi-utf
%config(noreplace) %{_sysconfdir}/nginx/koi-win
%if ! 0%{?with_mailcap_mimetypes}
%config(noreplace) %{_sysconfdir}/nginx/mime.types
%endif
%config(noreplace) %{_sysconfdir}/nginx/mime.types.default
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf.default
%config(noreplace) %{_sysconfdir}/nginx/scgi_params
%config(noreplace) %{_sysconfdir}/nginx/scgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/win-utf
%if %{with geoip2}
%config(noreplace) %{_sysconfdir}/nginx/conf.d/geoip2.conf
%endif
%if %{with brotli}
%config(noreplace) %{_sysconfdir}/nginx/default.d/brotli.conf
%endif
%config(noreplace) %{_sysconfdir}/nginx/conf.d/x-security.conf
%config(noreplace) %{_sysconfdir}/nginx/default.d/deny-restrictions.conf
%config(noreplace) %{_sysconfdir}/nginx/default.d/gzip.conf
%config(noreplace) %{_sysconfdir}/nginx/sites-available/0-default.conf
%config(noreplace) %{_sysconfdir}/nginx/sites-enabled/0-default.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/nginx
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx/tmp
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/log/nginx
%dir %{nginx_moduledir}

%files core
%license LICENSE
%doc CHANGES README README.dynamic
%{_sbindir}/nginx
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf
%config(noreplace) %{_sysconfdir}/nginx/fastcgi.conf.default
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params
%config(noreplace) %{_sysconfdir}/nginx/fastcgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/koi-utf
%config(noreplace) %{_sysconfdir}/nginx/koi-win
%if ! 0%{?with_mailcap_mimetypes}
%config(noreplace) %{_sysconfdir}/nginx/mime.types
%endif
%config(noreplace) %{_sysconfdir}/nginx/mime.types.default
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf
%config(noreplace) %{_sysconfdir}/nginx/nginx.conf.default
%config(noreplace) %{_sysconfdir}/nginx/scgi_params
%config(noreplace) %{_sysconfdir}/nginx/scgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params
%config(noreplace) %{_sysconfdir}/nginx/uwsgi_params.default
%config(noreplace) %{_sysconfdir}/nginx/win-utf
%config(noreplace) %{_sysconfdir}/logrotate.d/nginx
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx
%attr(770,%{nginx_user},root) %dir %{_localstatedir}/lib/nginx/tmp
%attr(711,root,root) %dir %{_localstatedir}/log/nginx
%ghost %attr(640,%{nginx_user},root) %{_localstatedir}/log/nginx/access.log
%ghost %attr(640,%{nginx_user},root) %{_localstatedir}/log/nginx/error.log
%dir %{nginx_moduledir}
%dir %{nginx_moduleconfdir}

%files all-modules

%files filesystem
%dir %{_datadir}/nginx
%dir %{_datadir}/nginx/html
%dir %{_sysconfdir}/nginx
%dir %{_sysconfdir}/nginx/conf.d
%dir %{_sysconfdir}/nginx/default.d
%dir %{_sysconfdir}/nginx/sites-available
%dir %{_sysconfdir}/nginx/sites-enabled
%dir %{_sysconfdir}/systemd/system/nginx.service.d
%dir %{_unitdir}/nginx.service.d

%if %{with geoip}
%files mod-http-geoip
%{nginx_moduleconfdir}/mod-http-geoip.conf
%{nginx_moduledir}/ngx_http_geoip_module.so
%endif

%if %{with geoip2}
%files mod-http-geoip2
%{nginx_moduleconfdir}/mod-http-geoip2.conf
%{nginx_moduledir}/ngx_http_geoip2_module.so
%files mod-stream-geoip2
%{nginx_moduleconfdir}/mod-stream-geoip2.conf
%{nginx_moduledir}/ngx_stream_geoip2_module.so
%endif

%if %{with brotli}
%files mod-http-brotli-filter
%{nginx_moduleconfdir}/mod-http-brotli-filter.conf
%{nginx_moduledir}/ngx_http_brotli_filter_module.so
%files mod-http-brotli-static
%{nginx_moduleconfdir}/mod-http-brotli-static.conf
%{nginx_moduledir}/ngx_http_brotli_static_module.so
%endif

%if %{with fancyindex}
%files mod-http-fancyindex
%{nginx_moduleconfdir}/mod-http-fancyindex.conf
%{nginx_moduledir}/ngx_http_fancyindex_module.so
%endif

%if %{with rtmp}
%files mod-rtmp
%{nginx_moduleconfdir}/mod-rtmp.conf
%{nginx_moduledir}/ngx_rtmp_module.so
%endif

%files mod-http-image-filter
%{nginx_moduleconfdir}/mod-http-image-filter.conf
%{nginx_moduledir}/ngx_http_image_filter_module.so

%files mod-http-perl
%{nginx_moduleconfdir}/mod-http-perl.conf
%{nginx_moduledir}/ngx_http_perl_module.so
%dir %{perl_vendorarch}/auto/nginx
%{perl_vendorarch}/nginx.pm
%{perl_vendorarch}/auto/nginx/nginx.so

%files mod-http-xslt-filter
%{nginx_moduleconfdir}/mod-http-xslt-filter.conf
%{nginx_moduledir}/ngx_http_xslt_filter_module.so

%files mod-mail
%{nginx_moduleconfdir}/mod-mail.conf
%{nginx_moduledir}/ngx_mail_module.so

%files mod-stream
%{nginx_moduleconfdir}/mod-stream.conf
%{nginx_moduledir}/ngx_stream_module.so

%files mod-devel
%{_rpmmacrodir}/macros.nginxmods
%{_fileattrsdir}/nginxmods.attr
%{nginx_srcdir}/


%changelog
* Tue Apr 23 2024 Maxim Dounin - 1:1.26.0-1
- feature: 1.26.x stable branch.

* Tue Apr 16 2024 Maxim Dounin - 1:1.25.5-1
- feature: virtual servers in the stream module.
- feature: the ngx_stream_pass_module.
- feature: the "deferred", "accept_filter", and "setfib" parameters of the "listen" directive in the stream module.
- feature: cache line size detection for some architectures. Thanks to Piotr Sikora.
- feature: support for Homebrew on Apple Silicon. Thanks to Piotr Sikora.
- bugfix: Windows cross-compilation bugfixes and improvements. Thanks to Piotr Sikora.
- bugfix: unexpected connection closure while using 0-RTT in QUIC. Thanks to Vladimir Khomutov.

* Wed Feb 14 2024 Maxim Dounin - 1:1.25.4-1
- security: when using HTTP/3 a segmentation fault might occur in a worker process while processing a specially crafted QUIC session (CVE-2024-24989, CVE-2024-24990).
- bugfix: connections with pending AIO operations might be closed prematurely during graceful shutdown of old worker processes.
- bugfix: socket leak alerts no longer logged when fast shutdown was requested after graceful shutdown of old worker processes.
- bugfix: a socket descriptor error, a socket leak, or a segmentation fault in a worker process (for SSL proxying) might occur if AIO was used in a subrequest.
- bugfix: a segmentation fault might occur in a worker process if SSL proxying was used along with the "image_filter" directive and errors with code 415 were redirected with the "error_page" directive.
- bugfix: bugfixes and improvements in HTTP/3.

* Tue Oct 24 2023 Maxim Dounin - 1:1.25.3-1
- change: improved detection of misbehaving clients when using HTTP/2.
- feature: startup speedup when using a large number of locations. Thanks to Yusuke Nojima.
- bugfix: a segmentation fault might occur in a worker process when using HTTP/2 without SSL; the bug had appeared in 1.25.1.
- bugfix: the "Status" backend response header line with an empty reason phrase was handled incorrectly.
- bugfix: memory leak during reconfiguration when using the PCRE2 library. Thanks to ZhenZhong Wu.
- bugfix: bugfixes and improvements in HTTP/3.

* Tue Aug 15 2023 Maxim Dounin - 1:1.25.2-1
- feature: path MTU discovery when using HTTP/3.
- feature: TLS_AES_128_CCM_SHA256 cipher suite support when using HTTP/3.
- change: now nginx uses appname "nginx" when loading OpenSSL configuration.
- change: now nginx does not try to load OpenSSL configuration if the --with-openssl option was used to built OpenSSL and the OPENSSL_CONF environment variable is not set.
- bugfix: in the $body_bytes_sent variable when using HTTP/3.
- bugfix: in HTTP/3.

* Tue Jun 13 2023 Maxim Dounin - 1:1.25.1-1
- feature: the "http2" directive, which enables HTTP/2 on a per-server basis; the "http2" parameter of the "listen" directive is now deprecated.
- change: HTTP/2 server push support has been removed.
- change: the deprecated "ssl" directive is not supported anymore.
- bugfix: in HTTP/3 when using OpenSSL.

* Tue May 23 2023 Maxim Dounin - 1:1.25.0-1
- feature: experimental HTTP/3 support.

* Tue Apr 11 2023 Maxim Dounin - 1:1.24.0-1
- 1.24.x stable branch.

* Tue Mar 28 2023 Maxim Dounin - 1:1.23.4-1
- change: now TLSv1.3 protocol is enabled by default.
- change: now nginx issues a warning if protocol parameters of a listening socket are redefined.
- change: now nginx closes connections with lingering if pipelining was used by the client.
- feature: byte ranges support in the ngx_http_gzip_static_module.
- bugfix: port ranges in the "listen" directive did not work; the bug had appeared in 1.23.3. Thanks to Valentin Bartenev.
- bugfix: incorrect location might be chosen to process a request if a prefix location longer than 255 characters was used in the configuration.
- bugfix: non-ASCII characters in file names on Windows were not supported by the ngx_http_autoindex_module, the ngx_http_dav_module, and the "include" directive.
- change: the logging level of the "data length too long", "length too short", "bad legacy version", "no shared signature algorithms", "bad digest length", "missing sigalgs extension", "encrypted length too long", "bad length", "bad key update", "mixed handshake and non handshake data", "ccs received early", "data between ccs and finished", "packet length too long", "too many warn alerts", "record too small", and "got a fin before a ccs" SSL errors has been lowered from "crit" to "info".
- bugfix: a socket leak might occur when using HTTP/2 and the "error_page" directive to redirect errors with code 400.
- bugfix: messages about logging to syslog errors did not contain information that the errors happened while logging to syslog. Thanks to Safar Safarly.
- workaround: "gzip filter failed to use preallocated memory" alerts appeared in logs when using zlib-ng.
- bugfix: in the mail proxy server.

* Tue Dec 13 2022 Maxim Dounin - 1:1.23.3-1
- bugfix: an error might occur when reading PROXY protocol version 2 header with large number of TLVs.
- bugfix: a segmentation fault might occur in a worker process if SSI was used to process subrequests created by other modules. Thanks to Ciel Zhao.
- workaround: when a hostname used in the "listen" directive resolves to multiple addresses, nginx now ignores duplicates within these addresses.
- bugfix: nginx might hog CPU during unbuffered proxying if SSL connections to backends were used.

* Wed Oct 19 2022 Brian Rogers <captbrogers@protonmail.ch> - 1:1.23.2-1
- security: processing of a specially crafted mp4 file by the ngx_http_mp4_module might cause a worker process crash, worker process memory disclosure, or might have potential other impact (CVE-2022-41741, CVE-2022-41742).
- feature: the "$proxy_protocol_tlv_..." variables.
- feature: TLS session tickets encryption keys are now automatically rotated when using shared memory in the "ssl_session_cache" directive.
- change: the logging level of the "bad record type" SSL errors has been lowered from "crit" to "info". Thanks to Murilo Andrade.
- change: now when using shared memory in the "ssl_session_cache" directive the "could not allocate new session" errors are logged at the "warn" level instead of "alert" and not more often than once per second.
- bugfix: nginx/Windows could not be built with OpenSSL 3.0.x.
- bugfix: in logging of the PROXY protocol errors. Thanks to Sergey Brester.
- workaround: shared memory from the "ssl_session_cache" directive was spent on sessions using TLS session tickets when using TLSv1.3 with OpenSSL.
- workaround: timeout specified with the "ssl_session_timeout" directive did not work when using TLSv1.3 with OpenSSL or BoringSSL.

* Tue Jul 19 2022 1:1.23.1-1
- feature: memory usage optimization in configurations with SSL proxying.
- feature: looking up of IPv4 addresses while resolving now can be disabled with the "ipv4=off" parameter of the "resolver" directive.
- change: the logging level of the "bad key share", "bad extension", "bad cipher", and "bad ecpoint" SSL errors has been lowered from "crit" to "info".
- bugfix: while returning byte ranges nginx did not remove the "Content-Range" header line if it was present in the original backend response.
- bugfix: a proxied response might be truncated during reconfiguration on Linux; the bug had appeared in 1.17.5.

* Tue Jun 21 2022 1:1.23.0-1
- change in internal API: now header lines are represented as linked lists.
- change: now nginx combines arbitrary header lines with identical names when sending to FastCGI, SCGI, and uwsgi backends, in the $r->header_in() method of the ngx_http_perl_module, and during lookup of the "$http_...", "$sent_http_...", "$sent_trailer_...", "$upstream_http_...", and "$upstream_trailer_..." variables.
- bugfix: if there were multiple "Vary" header lines in the backend response, nginx only used the last of them when caching.
- bugfix: if there were multiple "WWW-Authenticate" header lines in the backend response and errors with code 401 were intercepted or the "auth_request" directive was used, nginx only sent the first of the header lines to the client.
- change: the logging level of the "application data after close notify" SSL errors has been lowered from "crit" to "info".
- bugfix: connections might hang if nginx was built on Linux 2.6.17 or newer, but was used on systems without EPOLLRDHUP support, notably with epoll emulation layers; the bug had appeared in 1.17.5. Thanks to Marcus Ball.
- bugfix: nginx did not cache the response if the "Expires" response header line disabled caching, but following "Cache-Control" header line enabled caching.

* Tue May 24 2022 1:1.22.0-1
- 1.22.x stable branch.

* Tue Jan 25 2022 1:1.21.6-1
- bugfix: when using EPOLLEXCLUSIVE on Linux client connections were unevenly distributed among worker processes.
- bugfix: nginx returned the "Connection: keep-alive" header line in responses during graceful shutdown of old worker processes.
- bugfix: in the "ssl_session_ticket_key" when using TLSv1.3.

* Tue Dec 28 2021 1:1.21.5-1
- change: now nginx is built with the PCRE2 library by default.
- change: now nginx always uses sendfile(SF_NODISKIO) on FreeBSD.
- feature: support for sendfile(SF_NOCACHE) on FreeBSD.
- feature: the $ssl_curve variable.
- bugfix: connections might hang when using HTTP/2 without SSL with the "sendfile" and "aio" directives.

* Tue Nov 02 2021 1:1.21.4-1
- change: support for NPN instead of ALPN to establish HTTP/2 connections has been removed.
- change: now nginx rejects SSL connections if ALPN is used by the client, but no supported protocols can be negotiated.
- change: the default value of the "sendfile_max_chunk" directive was changed to 2 megabytes.
- change: Updated ngx-fancyindex to v0.5.2
- feature: the "proxy_half_close" directive in the stream module.
- feature: the "ssl_alpn" directive in the stream module.
- feature: the $ssl_alpn_protocol variable.
- feature: support for SSL_sendfile() when using OpenSSL 3.0.
- feature: the "mp4_start_key_frame" directive in the ngx_http_mp4_module. Thanks to Tracey Jaquith.
- bugfix: in the $content_length variable when using chunked transfer encoding.
- bugfix: after receiving a response with incorrect length from a proxied backend nginx might nevertheless cache the connection. Thanks to Awdhesh Mathpal.
- bugfix: invalid headers from backends were logged at the "info" level instead of "error"; the bug had appeared in 1.21.1.
- bugfix: requests might hang when using HTTP/2 and the "aio_write" directive.

* Tue Sep 07 2021 1:1.21.3-1
- change: optimization of client request body reading when using HTTP/2.
- bugfix: in request body filters internal API when using HTTP/2 and buffering of the data being processed.

* Tue Aug 31 2021 1:1.21.2-1
- change: now nginx rejects HTTP/1.0 requests with the "Transfer-Encoding" header line.
- change: export ciphers are no longer supported.
- feature: OpenSSL 3.0 compatibility.
- feature: the "Auth-SSL-Protocol" and "Auth-SSL-Cipher" header lines are now passed to the mail proxy authentication server. Thanks to Rob Mueller.
- feature: request body filters API now permits buffering of the data being processed.
- feature: added brotli compression and rtmp module.
- bugfix: backend SSL connections in the stream module might hang after an SSL handshake.
- bugfix: the security level, which is available in OpenSSL 1.1.0 or newer, did not affect loading of the server certificates when set with "@SECLEVEL=N" in the "ssl_ciphers" directive.
- bugfix: SSL connections with gRPC backends might hang if select, poll, or /dev/poll methods were used.
- bugfix: when using HTTP/2 client request body was always written to disk if the "Content-Length" header line was not present in the request.

* Tue Jul 06 2021 1:1.21.1-1
- change: now nginx always returns an error for the CONNECT method.
- change: now nginx always returns an error if both "Content-Length" and "Transfer-Encoding" header lines are present in the request.
- change: now nginx always returns an error if spaces or control characters are used in the request line.
- change: now nginx always returns an error if spaces or control characters are used in a header name.
- change: now nginx always returns an error if spaces or control characters are used in the "Host" request header line.
- change: optimization of configuration testing when using many listening sockets.
- bugfix: nginx did not escape """, "<", ">", "\", "^", "`", "{", "|", and "}" characters when proxying with changed URI.
- bugfix: SSL variables might be empty when used in logs; the bug had appeared in 1.19.5.
- bugfix: keepalive connections with gRPC backends might not be closed after receiving a GOAWAY frame.
- bugfix: reduced memory consumption for long-lived requests when proxying with more than 64 buffers.

* Tue May 25 2021 1:1.21.0-1
- security: 1-byte memory overwrite might occur during DNS server response processing if the "resolver" directive was used, allowing an attacker who is able to forge UDP packets from the DNS server to cause worker process crash or, potentially, arbitrary code execution (CVE-2021-23017).
- feature: variables support in the "proxy_ssl_certificate", "proxy_ssl_certificate_key" "grpc_ssl_certificate", "grpc_ssl_certificate_key", "uwsgi_ssl_certificate", and "uwsgi_ssl_certificate_key" directives.
- feature: the "max_errors" directive in the mail proxy module.
- feature: the mail proxy module supports POP3 and IMAP pipelining.
- feature: the "fastopen" parameter of the "listen" directive in the stream module. Thanks to Anbang Wen.
- bugfix: special characters were not escaped during automatic redirect with appended trailing slash.
- bugfix: connections with clients in the mail proxy module might be closed unexpectedly when using SMTP pipelining.

* Wed Apr 28 2021 1:1.19.10-2
- added: brotli compression.

* Tue Apr 13 2021 1:1.19.10-1
 - change: the default value of the "keepalive_requests" directive was changed to 1000.
 - feature: the "keepalive_time" directive.
 - feature: the $connection_time variable.
 - workaround: "gzip filter failed to use preallocated memory" alerts appeared in logs when using zlib-ng.

* Tue Mar 30 2021 1:1.19.9-1
 - bugfix: nginx could not be built with the mail proxy module, but without the ngx_mail_ssl_module; the bug had appeared in 1.19.8.
 - bugfix: "upstream sent response body larger than indicated content length" errors might occur when working with gRPC backends; the bug had appeared in 1.19.1.
 - bugfix: nginx might not close a connection till keepalive timeout expiration if the connection was closed by the client while discarding the request body.
 - bugfix: nginx might not detect that a connection was already closed by the client when waiting for auth_delay or limit_req delay, or when working with backends.
 - bugfix: in the eventport method.

* Tue Mar 09 2021 1:1.19.8-1
 - feature: flags in the "proxy_cookie_flags" directive can now contain variables.
 - feature: the "proxy_protocol" parameter of the "listen" directive, the "proxy_protocol" and "set_real_ip_from" directives in mail proxy.
 - bugfix: HTTP/2 connections were immediately closed when using "keepalive_timeout 0"; the bug had appeared in 1.19.7.
 - bugfix: some errors were logged as unknown if nginx was built with glibc 2.32.
 - bugfix: in the eventport method.

* Tue Feb 16 2021 1:1.19.7-1
 - change: connections handling in HTTP/2 has been changed to better match HTTP/1.x; the "http2_recv_timeout", "http2_idle_timeout", and "http2_max_requests" directives have been removed, the "keepalive_timeout" and "keepalive_requests" directives should be used instead.
 - change: the "http2_max_field_size" and "http2_max_header_size" directives have been removed, the "large_client_header_buffers" directive should be used instead.
 - feature: now, if free worker connections are exhausted, nginx starts closing not only keepalive connections, but also connections in lingering close.
 - bugfix: "zero size buf in output" alerts might appear in logs if an upstream server returned an incorrect response during unbuffered proxying; the bug had appeared in 1.19.1.
 - bugfix: HEAD requests were handled incorrectly if the "return" directive was used with the "image_filter" or "xslt_stylesheet" directives.
 - bugfix: in the "add_trailer" directive.
 - change: removed fancyindex from build.

* Tue Dec 15 2020 1:1.19.6-1
 - bugfix: "no live upstreams" errors if a "server" inside "upstream" block was marked as "down".
 - bugfix: a segmentation fault might occur in a worker process if HTTPS was used; the bug had appeared in 1.19.5.
 - bugfix: nginx returned the 400 response on requests like "GET http://example.com?args HTTP/1.0".
 - bugfix: in the ngx_http_flv_module and ngx_http_mp4_module. Thanks to Chris Newton.

* Tue Nov 24 2020 1:1.19.5-1
 - feature: the -e switch.
 - feature: the same source files can now be specified in different modules while building addon modules.
 - bugfix: SSL shutdown did not work when lingering close was used.
 - bugfix: "upstream sent frame for closed stream" errors might occur when working with gRPC backends.
 - bugfix: in request body filters internal API.

* Tue Oct 27 2020 1:1.19.4-1
 - feature: the "ssl_conf_command", "proxy_ssl_conf_command", "grpc_ssl_conf_command", and "uwsgi_ssl_conf_command" directives.
 - feature: the "ssl_reject_handshake" directive.
 - feature: the "proxy_smtp_auth" directive in mail proxy.

* Tue Sep 29 2020 1:1.19.3-1
 - feature: the ngx_stream_set_module.
 - feature: the "proxy_cookie_flags" directive.
 - feature: the "userid_flags" directive.
 - bugfix: the "stale-if-error" cache control extension was erroneously applied if backend returned a response with status code 500, 502, 503, 504, 403, 404, or 429.
 - bugfix: "[crit] cache file ... has too long header" messages might appear in logs if caching was used and the backend returned responses with the "Vary" header line.
 - workaround: "[crit] SSL_write() failed" messages might appear in logs when using OpenSSL 1.1.1.
 - bugfix: "SSL_shutdown() failed (SSL: ... bad write retry)" messages might appear in logs; the bug had appeared in 1.19.2.
 - bugfix: a segmentation fault might occur in a worker process when using HTTP/2 if errors with code 400 were redirected to a proxied location using the "error_page" directive.
 - bugfix: socket leak when using HTTP/2 and subrequests in the njs module.

* Tue Aug 11 2020 1:1.19.2-1
- change: now nginx starts closing keepalive connections before all free worker connections are exhausted, and logs a warning about this to the error log.
- change: optimization of client request body reading when using chunked transfer encoding.
- bugfix: memory leak if the "ssl_ocsp" directive was used.
- bugfix: "zero size buf in output" alerts might appear in logs if a FastCGI server returned an incorrect response; the bug had appeared in 1.19.1.
- bugfix: a segmentation fault might occur in a worker process if different large_client_header_buffers sizes were used in different virtual servers.
- bugfix: SSL shutdown might not work.
- bugfix: "SSL_shutdown() failed (SSL: ... bad write retry)" messages might appear in logs.
- bugfix: in the ngx_http_slice_module.
- bugfix: in the ngx_http_xslt_filter_module.

* Tue Jul 07 2020 1:1.19.1-1
- change: the "lingering_close", "lingering_time", and "lingering_timeout" directives now work when using HTTP/2.
- change: now extra data sent by a backend are always discarded.
- change: now after receiving a too short response from a FastCGI server nginx tries to send the available part of the response to the client, and then closes the client connection.
- change: now after receiving a response with incorrect length from a gRPC backend nginx stops response processing with an error.
- feature: the "min_free" parameter of the "proxy_cache_path", "fastcgi_cache_path", "scgi_cache_path", and "uwsgi_cache_path" directives. Thanks to Adam Bambuch.
- bugfix: nginx did not delete unix domain listen sockets during graceful shutdown on the SIGQUIT signal.
- bugfix: zero length UDP datagrams were not proxied.
- bugfix: proxying to uwsgi backends using SSL might not work. Thanks to Guanzhong Chen.
- bugfix: in error handling when using the "ssl_ocsp" directive.
- bugfix: on XFS and NFS file systems disk cache size might be calculated incorrectly.
- bugfix: "negative size buf in writer" alerts might appear in logs if a memcached server returned a malformed response.

* Tue May 26 2020 1:1.19.0-1
- feature: client certificate validation with OCSP.
- bugfix: "upstream sent frame for closed stream" errors might occur when working with gRPC backends.
- bugfix: OCSP stapling might not work if the "resolver" directive was not specified.
- bugfix: connections with incorrect HTTP/2 preface were not logged.

* Tue Apr 14 2020 1:1.17.10-1
- feature: the "auth_delay" directive.

* Tue Mar 03 2020 1:1.17.9-1
- change: now nginx does not allow several "Host" request header lines.
- bugfix: nginx ignored additional "Transfer-Encoding" request header lines.
- bugfix: socket leak when using HTTP/2.
- bugfix: a segmentation fault might occur in a worker process if OCSP stapling was used.
- bugfix: in the ngx_http_mp4_module.
- bugfix: nginx used status code 494 instead of 400 if errors with code 494 were redirected with the "error_page" directive.
- bugfix: socket leak when using subrequests in the njs module and the "aio" directive.

* Tue Jan 21 2020 - 1:1.17.8
- feature: variables support in the "grpc_pass" directive.
- bugfix: a timeout might occur while handling pipelined requests in an SSL connection; the bug had appeared in 1.17.5.
- bugfix: in the "debug_points" directive when using HTTP/2. Thanks to Daniil Bondarev.

* Wed Jan 8 2020 - 1:1.17.7-2
- feature: Added ngx_http_fancyindex_module.
- change: Removed http_flv_module.

* Tue Dec 24 2019 - 1:1.17.7-1
- bugfix: a segmentation fault might occur on start or during reconfiguration if the "rewrite" directive with an empty replacement string was used in the configuration.
- bugfix: a segmentation fault might occur in a worker process if the "break" directive was used with the "alias" directive or with the "proxy_pass" directive with a URI.
- bugfix: the "Location" response header line might contain garbage if the request URI was rewritten to the one containing a null character.
- bugfix: requests with bodies were handled incorrectly when returning redirections with the "error_page" directive; the bug had appeared in 0.7.12.
- bugfix: socket leak when using HTTP/2.
- bugfix: a timeout might occur while handling pipelined requests in an SSL connection; the bug had appeared in 1.17.5.
- bugfix: in the ngx_http_dav_module.

* Tue Nov 19 2019 - 1:1.17.6-1
- feature: the $proxy_protocol_server_addr and $proxy_protocol_server_port variables.
- feature: the "limit_conn_dry_run" directive.
- feature: the $limit_req_status and $limit_conn_status variables.

* Tue Oct 22 2019 - 1:1.17.5-1
- feature: now nginx uses ioctl(FIONREAD), if available, to avoid reading from a fast connection for a long time.
- bugfix: incomplete escaped characters at the end of the request URI were ignored.
- bugfix: "/." and "/.." at the end of the request URI were not normalized.
- bugfix: in the "merge_slashes" directive.
- bugfix: in the "ignore_invalid_headers" directive. Thanks to Alan Kemp.
- bugfix: nginx could not be built with MinGW-w64 gcc 8.1 or newer.

* Tue Sep 24 2019 - 1:1.17.4-1
- change: better detection of incorrect client behavior in HTTP/2.
- change: in handling of not fully read client request body when returning errors in HTTP/2.
- bugfix: the "worker_shutdown_timeout" directive might not work when using HTTP/2.
- bugfix: a segmentation fault might occur in a worker process when using HTTP/2 and the "proxy_request_buffering" directive.
- bugfix: the ECONNABORTED error log level was "crit" instead of "error" on Windows when using SSL.
- bugfix: nginx ignored extra data when using chunked transfer encoding.
- bugfix: nginx always returned the 500 error if the "return" directive was used and an error occurred during reading client request body.
- bugfix: in memory allocation error handling.

* Tue Aug 13 2019 - 1:1.17.3-1
- security: when using HTTP/2 a client might cause excessive memory consumption and CPU usage (CVE-2019-9511, CVE-2019-9513, CVE-2019-9516).
- bugfix: "zero size buf" alerts might appear in logs when using gzipping; the bug had appeared in 1.17.2.
- bugfix: a segmentation fault might occur in a worker process if the "resolver" directive was used in SMTP proxy.

* Sun Jul 07 2019 - 1:1.17.2-1
- change: Minimum support zlib version is 1.2.0.4
- change: the $r->internal_redirect() embedded perl methond now expects escaped URIs.
- feature: it is now possible to switch to a named location using the $r->internal_redirect() embedded perl methond
- bugfix: in error handling in embedded perl
- bugfix: a segmentation fault might occur on start or during reconfiguration
- bugfix: nginx might hog CPU during unbuffered proxying and when proxying WebSocket connections if the select, poll, or /dev/poll methods are used
- bugfix: in the ngx_http_xslt_filter_module
- bugfix: in the ngx_http_ssi_filter_module

* Tue Jun 25 2019 - 1:1.17.1
- feature: the "limit_req_dry_run" directive
- feature: when using the "hash" directive inside the "upstream" block an empty hash key now triggers round-robin balancing
- bugfix: a segfault might occur in a worker process if catching was used along the "image_filter" directive, and errors with code 415 were redirected with the "error_page" directive; the bug had appeared in 1.11.10
- bugfix: a segfault might occur in a worker process if embedded perl was used; the bug had appeared in 1.7.3

* Tue May 21 2019 - 1:1.17.0
- feature: variables support in the "limit_rate" and "limit_rate_after" directives
- feature: variables support in the "proxy_upload_rate" and "proxy_download_rate" directives in the stream module
- change: minimum supported OpenSSL version is 0.9.8
- change: now the postpone filter is always built
- bugfix: the "include" directive did not work inside the "if" and "limit_except" blocks
- bugfix: in byte ranges processing

* Tue Apr 16 2019 - 1:1.15.12
- bugfix: a segfault might occur in a worker process if variables were used in the "ssl_certificate" or "ssl_certificate_key" directives and OCSP stapling was enabled

* Tue Apr 09 2019 - 1:1.15.11
- bugfix: in the "ssl_stapling_file" directive on Windows

* Tue Mar 26 2019 - 1:1.15.10
- change: when using a hostname in the "listen" directive nginx now 
- feature: port ranges in the "listen" directive creates listening sockets for all addresses the hostname resolves to (previously, only the first address was used)
- feature: loading of SSL certificates and secret keys from variables
- workaround: the the $ssl_server_name variable might be empty when using OpenSSL 1.1.1
- bugfix: nginx/Windows could not be built with Visual Studio 2015 or newer; the bug had appeared in 1.15.9

* Mon Mar 04 2019 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.15.9-1
- Update to upstream release 1.15.9
- Enable ngx_stream_ssl_preread module
- Remove redundant conditionals

* Fri Feb 01 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.14.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jan 14 2019 Björn Esser <besser82@fedoraproject.org> - 1:1.14.1-4
- Rebuilt for libcrypt.so.2 (#1666033)

* Tue Dec 11 2018 Joe Orton <jorton@redhat.com> - 1:1.14.1-3
- fix unexpanded paths in nginx(8)

* Tue Nov 20 2018 Luboš Uhliarik <luhliari@redhat.com> - 1:1.14.1-2
- new version 1.14.1
- Resolves: #1584426 - Upstream Nginx 1.14.0 is now available
- Resolves: #1647255 - CVE-2018-16845 nginx: Denial of service and memory
  disclosure via mp4 module
- Resolves: #1647259 - CVE-2018-16843 nginx: Excessive memory consumption
  via flaw in HTTP/2 implementation
- Resolves: #1647258 - CVE-2018-16844 nginx: Excessive CPU usage via flaw
  in HTTP/2 implementation

* Mon Aug 06 2018 Luboš Uhliarik <luhliari@redhat.com> - 1:1.12.1-14
- add requires on perl(constant) for mod-http-perl

* Mon Jul 30 2018 Luboš Uhliarik <luhliari@redhat.com> - 1:1.12.1-13
- don't build with geoip by default

* Thu Jul 19 2018 Joe Orton <jorton@redhat.com> - 1:1.12.1-12
- add build conditional for geoip support

* Mon Jul 16 2018 Tadej Janež <tadej.j@nez.si> - 1:1.12.1-11
- Add gcc to BuildRequires to account for
  https://fedoraproject.org/wiki/Changes/Remove_GCC_from_BuildRoot

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.12.1-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Jun 27 2018 Jitka Plesnikova <jplesnik@redhat.com> - 1:1.12.1-9
- Perl 5.28 rebuild

* Mon May 14 2018 Luboš Uhliarik <luhliari@redhat.com> - 1:1.12.1-8
- Related: #1573942 - nginx fails on start

* Wed May 02 2018 Luboš Uhliarik <luhliari@redhat.com> - 1:1.12.1-7
- Resolves: #1573942 - nginx fails on start

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.12.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Jan 24 2018 Björn Esser <besser82@fedoraproject.org> - 1:1.12.1-5
- Add patch to apply glibc bugfix if really needed only
- Disable strict symbol checks in the link editor

* Sat Jan 20 2018 Björn Esser <besser82@fedoraproject.org> - 1:1.12.1-4
- Rebuilt for switch to libxcrypt

* Tue Oct 24 2017 Joe Orton <jorton@redhat.com> - 1:1.12.1-3
- rebuild

* Tue Sep 19 2017 Remi Collet <remi@fedoraproject.org> - 1:1.12.1-2
- own system drop-in directories #1493036

* Tue Aug 15 2017 Joe Orton <jorton@redhat.com> - 1:1.12.1-1
- update to 1.12.1 (#1469924)
- enable http_auth_request_module (Tim Niemueller, #1471106)

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.12.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.12.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jun 04 2017 Jitka Plesnikova <jplesnik@redhat.com> - 1:1.12.0-2
- Perl 5.26 rebuild

* Tue May 30 2017 Luboš Uhliarik <luhliari@redhat.com> - 1:1.12.0-1
- new version 1.12.0

* Wed Feb  8 2017 Joe Orton <jorton@redhat.com> - 1:1.10.3-1
- update to upstream release 1.10.3

* Mon Oct 31 2016 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.10.2-1
- update to upstream release 1.10.2

* Tue May 31 2016 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.10.1-1
- update to upstream release 1.10.1

* Sun May 15 2016 Jitka Plesnikova <jplesnik@redhat.com> - 1:1.10.0-4
- Perl 5.24 rebuild

* Sun May  8 2016 Peter Robinson <pbrobinson@fedoraproject.org> 1:1.10.0-3
- Enable AIO on aarch64 (rhbz 1258414)

* Wed Apr 27 2016 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.10.0-2
- only Require nginx-all-modules for EPEL and current Fedora releases

* Wed Apr 27 2016 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.10.0-1
- update to upstream release 1.10.0
- split dynamic modules into subpackages
- spec file cleanup

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1:1.8.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Tue Jan 26 2016 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.1-1
- update to upstream release 1.8.1
- CVE-2016-0747: Insufficient limits of CNAME resolution in resolver
- CVE-2016-0746: Use-after-free during CNAME response processing in resolver
- CVE-2016-0742: Invalid pointer dereference in resolver

* Sun Oct 04 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-14
- consistently use '%%global with_foo' style of logic
- remove PID file before starting nginx (#1268621)

* Fri Sep 25 2015 Ville Skyttä <ville.skytta@iki.fi> - 1:1.8.0-13
- Use nginx-mimetypes from mailcap (#1248736)
- Mark LICENSE as %%license

* Thu Sep 10 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-12
- also build with gperftools on aarch64 (#1258412)

* Wed Aug 12 2015 Nikos Mavrogiannopoulos <nmav@redhat.com> - 1:1.8.0-11
- nginx.conf: added commented-out SSL configuration directives (#1179232)

* Fri Jul 03 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-10
- switch back to /bin/kill in logrotate script due to SELinux denials

* Tue Jun 16 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-9
- fix path to png in error pages (#1232277)
- optimize png images with optipng

* Sun Jun 14 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-8
- replace /bin/kill with /usr/bin/systemctl kill in logrotate script (#1231543)
- remove After=syslog.target in nginx.service (#1231543)
- replace ExecStop with KillSignal=SIGQUIT in nginx.service (#1231543)

* Wed Jun 03 2015 Jitka Plesnikova <jplesnik@redhat.com> - 1:1.8.0-7
- Perl 5.22 rebuild

* Sun May 10 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-6
- revert previous change

* Sun May 10 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-5
- move default server to default.conf (#1220094)

* Sun May 10 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-4
- add TimeoutStopSec=5 and KillMode=mixed to nginx.service
- set worker_processes to auto
- add some common options to the http block in nginx.conf
- run nginx-upgrade on package update
- remove some redundant scriptlet commands
- listen on ipv6 for default server (#1217081)

* Wed Apr 22 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-3
- improve nginx-upgrade script

* Wed Apr 22 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-2
- add --with-pcre-jit

* Wed Apr 22 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.8.0-1
- update to upstream release 1.8.0

* Thu Apr 09 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.7.12-1
- update to upstream release 1.7.12

* Sun Feb 15 2015 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.7.10-1
- update to upstream release 1.7.10
- remove systemd conditionals

* Wed Oct 22 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.2-4
- fix package ownership of directories

* Wed Oct 22 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.2-3
- add vim files (#1142849)

* Mon Sep 22 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.2-2
- create nginx-filesystem subpackage (patch from Remi Collet)
- create /etc/nginx/default.d as a drop-in directory for configuration files
  for the default server block
- clean up nginx.conf

* Wed Sep 17 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.2-1
- update to upstream release 1.6.2
- CVE-2014-3616 nginx: virtual host confusion (#1142573)

* Wed Aug 27 2014 Jitka Plesnikova <jplesnik@redhat.com> - 1:1.6.1-4
- Perl 5.20 rebuild

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.6.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Tue Aug 05 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.1-2
- add logic for EPEL 7

* Tue Aug 05 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.1-1
- update to upstream release 1.6.1
- (#1126891) CVE-2014-3556: SMTP STARTTLS plaintext injection flaw

* Wed Jul 02 2014 Yaakov Selkowitz <yselkowi@redhat.com> - 1:1.6.0-3
- Fix FTBFS on aarch64 (#1115559)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sat Apr 26 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.6.0-1
- update to upstream release 1.6.0

* Tue Mar 18 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.7-1
- update to upstream release 1.4.7

* Wed Mar 05 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.6-1
- update to upstream release 1.4.6

* Sun Feb 16 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.5-2
- avoid multiple index directives (#1065488)

* Sun Feb 16 2014 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.5-1
- update to upstream release 1.4.5

* Wed Nov 20 2013 Peter Borsa <peter.borsa@gmail.com> - 1:1.4.4-1
- Update to upstream release 1.4.4
- Security fix BZ 1032267

* Sun Nov 03 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.3-1
- update to upstream release 1.4.3

* Fri Aug 09 2013 Jonathan Steffan <jsteffan@fedoraproject.org> - 1:1.4.2-3
- Add in conditionals to build for non-systemd targets

* Sat Aug 03 2013 Petr Pisar <ppisar@redhat.com> - 1:1.4.2-2
- Perl 5.18 rebuild

* Fri Jul 19 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.2-1
- update to upstream release 1.4.2

* Wed Jul 17 2013 Petr Pisar <ppisar@redhat.com> - 1:1.4.1-3
- Perl 5.18 rebuild

* Tue Jun 11 2013 Remi Collet <rcollet@redhat.com> - 1:1.4.1-2
- rebuild for new GD 2.1.0

* Tue May 07 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.1-1
- update to upstream release 1.4.1 (#960605, #960606):
  CVE-2013-2028 stack-based buffer overflow when handling certain chunked
  transfer encoding requests

* Sun Apr 28 2013 Dan Horák <dan[at]danny.cz> - 1:1.4.0-2
- gperftools exist only on selected arches

* Fri Apr 26 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.4.0-1
- update to upstream release 1.4.0
- enable SPDY module (new in this version)
- enable http gunzip module (new in this version)
- enable google perftools module and add gperftools-devel to BR
- enable debugging (#956845)
- trim changelog

* Tue Apr 02 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.8-1
- update to upstream release 1.2.8

* Fri Feb 22 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.7-2
- make sure nginx directories are not world readable (#913724, #913735)

* Sat Feb 16 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.7-1
- update to upstream release 1.2.7
- add .asc file

* Tue Feb 05 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-6
- use 'kill' instead of 'systemctl' when rotating log files to workaround
  SELinux issue (#889151)

* Wed Jan 23 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-5
- uncomment "include /etc/nginx/conf.d/*.conf by default but leave the
  conf.d directory empty (#903065)

* Wed Jan 23 2013 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-4
- add comment in nginx.conf regarding "include /etc/nginf/conf.d/*.conf"
  (#903065)

* Wed Dec 19 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-3
- use correct file ownership when rotating log files

* Tue Dec 18 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-2
- send correct kill signal and use correct file permissions when rotating
  log files (#888225)
- send correct kill signal in nginx-upgrade

* Tue Dec 11 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.6-1
- update to upstream release 1.2.6

* Sat Nov 17 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.5-1
- update to upstream release 1.2.5

* Sun Oct 28 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.4-1
- update to upstream release 1.2.4
- introduce new systemd-rpm macros (#850228)
- link to official documentation not the community wiki (#870733)
- do not run systemctl try-restart after package upgrade to allow the
  administrator to run nginx-upgrade and avoid downtime
- add nginx man page (#870738)
- add nginx-upgrade man page and remove README.fedora
- remove chkconfig from Requires(post/preun)
- remove initscripts from Requires(preun/postun)
- remove separate configuration files in "/etc/nginx/conf.d" directory
  and revert to upstream default of a centralized nginx.conf file
  (#803635) (#842738)

* Fri Sep 21 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.3-1
- update to upstream release 1.2.3

* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1:1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 28 2012 Petr Pisar <ppisar@redhat.com> - 1:1.2.1-2
- Perl 5.16 rebuild

* Sun Jun 10 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.1-1
- update to upstream release 1.2.1

* Fri Jun 08 2012 Petr Pisar <ppisar@redhat.com> - 1:1.2.0-2
- Perl 5.16 rebuild

* Wed May 16 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.2.0-1
- update to upstream release 1.2.0

* Wed May 16 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.15-4
- add nginx-upgrade to replace functionality from the nginx initscript
  that was lost after migration to systemd
- add README.fedora to describe usage of nginx-upgrade
- nginx.logrotate: use built-in systemd kill command in postrotate script
- nginx.service: start after syslog.target and network.target
- nginx.service: remove unnecessary references to config file location
- nginx.service: use /bin/kill instead of "/usr/sbin/nginx -s" following
  advice from nginx-devel
- nginx.service: use private /tmp

* Mon May 14 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.15-3
- fix incorrect postrotate script in nginx.logrotate

* Thu Apr 19 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.15-2
- renable auto-cc-gcc patch due to warnings on rawhide

* Sat Apr 14 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.15-1
- update to upstream release 1.0.15
- no need to apply auto-cc-gcc patch
- add %%global _hardened_build 1

* Thu Mar 15 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.14-1
- update to upstream release 1.0.14
- amend some %%changelog formatting

* Tue Mar 06 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.13-1
- update to upstream release 1.0.13
- amend --pid-path and --log-path

* Sun Mar 04 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.12-5
- change pid path in nginx.conf to match systemd service file

* Sun Mar 04 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.12-3
- fix %%pre scriptlet

* Mon Feb 20 2012 Jamie Nguyen <jamielinux@fedoraproject.org> - 1:1.0.12-2
- update upstream URL
- replace %%define with %%global
- remove obsolete BuildRoot tag, %%clean section and %%defattr
- remove various unnecessary commands
- add systemd service file and update scriptlets
- add Epoch to accommodate %%triggerun as part of systemd migration

* Sun Feb 19 2012 Jeremy Hinegardner <jeremy at hinegardner dot org> - 1.0.12-1
- Update to 1.0.12

* Thu Nov 17 2011 Keiran "Affix" Smith <fedora@affix.me> - 1.0.10-1
- bugfix: a segmentation fault might occur in a worker process if resolver got a big DNS response. Thanks to Ben Hawkes.
- bugfix: in cache key calculation if internal MD5 implementation wasused; the bug had appeared in 1.0.4.
- bugfix: the module ngx_http_mp4_module sent incorrect "Content-Length" response header line if the "start" argument was used. Thanks to Piotr Sikora.

* Thu Oct 27 2011 Keiran "Affix" Smith <fedora@affix.me> - 1.0.8-1
- Update to new 1.0.8 stable release

* Fri Aug 26 2011 Keiran "Affix" Smith <fedora@affix.me> - 1.0.5-1
- Update nginx to Latest Stable Release

* Fri Jun 17 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0.0-3
- Perl mass rebuild

* Thu Jun 09 2011 Marcela Mašláňová <mmaslano@redhat.com> - 1.0.0-2
- Perl 5.14 mass rebuild

* Wed Apr 27 2011 Jeremy Hinegardner <jeremy at hinegardner dot org> - 1.0.0-1
- Update to 1.0.0

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.53-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Sun Dec 12 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.8.53.5
- Extract out default config into its own file (bug #635776)

* Sun Dec 12 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.8.53-4
- Revert ownership of log dir

* Sun Dec 12 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.8.53-3
- Change ownership of /var/log/nginx to be 0700 nginx:nginx
- update init script to use killproc -p
- add reopen_logs command to init script
- update init script to use nginx -q option

* Sun Oct 31 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.8.53-2
- Fix linking of perl module

* Sun Oct 31 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.8.53-1
- Update to new stable 0.8.53

* Sat Jul 31 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.7.67-2
- add Provides: webserver (bug #619693)

* Sun Jun 20 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.7.67-1
- Update to new stable 0.7.67
- fix bugzilla #591543

* Tue Jun 01 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.7.65-2
- Mass rebuild with perl-5.12.0

* Mon Feb 15 2010 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.7.65-1
- Update to new stable 0.7.65
- change ownership of logdir to root:root
- add support for ipv6 (bug #561248)
- add random_index_module
- add secure_link_module

* Fri Dec 04 2009 Jeremy Hinegardner <jeremy at hinegardner dot org> - 0.7.64-1
- Update to new stable 0.7.64
